@@ -54,16 +54,16 @@ class Cursor(object):
 
         if parameters:
             # # optional requirement
+            import six
             from psycopg2.extensions import adapt
 
             if isinstance(parameters, dict):
                 for key in parameters:
                     param = parameters[key]
                     # Make sure adapt() behaves properly
-                    if isinstance(param, str):
-                        v = adapt(param.encode('utf8')).getquoted()
-                    else:
-                        v = adapt(param).getquoted()
+                    if six.PY2:
+                        param = param.encode('utf8')
+                    v = adapt(param).getquoted()
 
                     # Using a regex with word boundary to correctly handle params with similar names
                     # such as :s and :start
@@ -217,6 +217,10 @@ class Cursor(object):
 
         while True:
             message = self.connection.read_message()
+
+            if isinstance(message, messages.ErrorResponse):
+                raise errors.QueryError.from_error_response(message, sql)
+
             self.connection.process_message(message=message)
             if isinstance(message, messages.ReadyForQuery):
                 break
